@@ -4,18 +4,26 @@ pub mod body_1;
 pub use self::body_1::Body1;
 pub mod protobuf_any;
 pub use self::protobuf_any::ProtobufAny;
-pub mod rpc_status;
-pub use self::rpc_status::RpcStatus;
 pub mod v1_accelerator;
 pub use self::v1_accelerator::V1Accelerator;
+pub mod v1_create_sip_teleport;
+pub use self::v1_create_sip_teleport::V1CreateSipTeleport;
 pub mod v1_list_accelerators_response;
 pub use self::v1_list_accelerators_response::V1ListAcceleratorsResponse;
+pub mod v1_list_projects_response;
+pub use self::v1_list_projects_response::V1ListProjectsResponse;
+pub mod v1_list_sessions_response;
+pub use self::v1_list_sessions_response::V1ListSessionsResponse;
 pub mod v1_list_sip_teleport_response;
 pub use self::v1_list_sip_teleport_response::V1ListSipTeleportResponse;
 pub mod v1_next_page;
 pub use self::v1_next_page::V1NextPage;
+pub mod v1_project;
+pub use self::v1_project::V1Project;
 pub mod v1_protocol;
 pub use self::v1_protocol::V1Protocol;
+pub mod v1_session;
+pub use self::v1_session::V1Session;
 pub mod v1_sip_teleport_response;
 pub use self::v1_sip_teleport_response::V1SipTeleportResponse;
 pub mod v1_sip_teleport_status;
@@ -24,3 +32,5 @@ pub mod v1_teleport_addresses;
 pub use self::v1_teleport_addresses::V1TeleportAddresses;
 pub mod v1_transport_type;
 pub use self::v1_transport_type::V1TransportType;
+pub mod v1_update_sip_teleport;
+pub use self::v1_update_sip_teleport::V1UpdateSipTeleport;
